@@ -1,4 +1,3 @@
-local fs = require "luacheck.fs"
 local utils = require "luacheck.utils"
 local multithreading = require "luacheck.multithreading"
 local helper = require "spec.helper"
@@ -832,137 +831,6 @@ Total: 3 warnings / 0 errors in 1 file
 ]], get_output "spec/samples/custom_std_inline_options.lua --config=spec/configs/custom_stds_config.luacheckrc")
    end)
 
-   describe("caching", function()
-      local tmpname
-
-      before_each(function()
-         tmpname = os.tmpname()
-
-         -- Work around os.tmpname being broken on Windows sometimes.
-         if utils.is_windows and not tmpname:find(':') then
-            tmpname = os.getenv("TEMP") .. tmpname
-         end
-      end)
-
-      after_each(function()
-         os.remove(tmpname)
-      end)
-
-      it("caches results", function()
-         local normal_output = [[
-Checking spec/samples/good_code.lua               OK
-Checking spec/samples/bad_code.lua                5 warnings
-
-    spec/samples/bad_code.lua:3:16: unused function 'helper'
-    spec/samples/bad_code.lua:3:23: unused variable length argument
-    spec/samples/bad_code.lua:7:10: setting non-standard global variable 'embrace'
-    spec/samples/bad_code.lua:8:10: variable 'opt' was previously defined as an argument on line 7
-    spec/samples/bad_code.lua:9:11: accessing undefined variable 'hepler'
-
-Checking spec/samples/python_code.lua             1 error
-
-    spec/samples/python_code.lua:1:6: expected '=' near '__future__'
-
-Total: 5 warnings / 1 error in 3 files
-]]
-
-         local mocked_output = [[
-Checking spec/samples/good_code.lua               1 error
-
-    spec/samples/good_code.lua:5:7: this code is actually bad
-
-Checking spec/samples/bad_code.lua                5 warnings
-
-    spec/samples/bad_code.lua:3:16: unused function 'helper'
-    spec/samples/bad_code.lua:3:23: unused variable length argument
-    spec/samples/bad_code.lua:7:10: setting non-standard global variable 'embrace'
-    spec/samples/bad_code.lua:8:10: variable 'opt' was previously defined as an argument on line 7
-    spec/samples/bad_code.lua:9:11: accessing undefined variable 'hepler'
-
-Checking spec/samples/python_code.lua             2 warnings
-
-    spec/samples/python_code.lua:1:1: setting non-standard global variable 'global'
-    spec/samples/python_code.lua:6:8: accessing uninitialized variable 'uninit'
-
-Checking spec/samples/unused_code.lua             9 warnings
-
-    spec/samples/unused_code.lua:3:18: unused argument 'baz'
-    spec/samples/unused_code.lua:4:8: unused loop variable 'i'
-    spec/samples/unused_code.lua:5:13: unused variable 'q'
-    spec/samples/unused_code.lua:7:11: unused loop variable 'a'
-    spec/samples/unused_code.lua:7:14: unused loop variable 'b'
-    spec/samples/unused_code.lua:7:17: unused loop variable 'c'
-    spec/samples/unused_code.lua:13:7: value assigned to variable 'x' is overwritten on line 14 before use
-    spec/samples/unused_code.lua:14:1: value assigned to variable 'x' is overwritten on line 15 before use
-    spec/samples/unused_code.lua:21:7: variable 'z' is never accessed
-
-Total: 16 warnings / 1 error in 4 files
-]]
-
-         assert.equal(normal_output, get_output("spec/samples/good_code.lua spec/samples/bad_code.lua spec/samples/python_code.lua --std=lua52 --no-config --cache "..tmpname))
-
-         local cache = utils.read_file(tmpname)
-         assert.string(cache)
-
-         local function replace_abspath(s)
-            return (s:gsub("abspath{(.-)}", function(p) return fs.normalize(fs.join(fs.get_current_dir(), p)) end))
-         end
-
-         -- luacheck: push no max string line length
-         local format_version, good_mtime, bad_mtime, python_mtime = cache:match(replace_abspath([[
-
-(%d+)
-abspath{spec/samples/good_code.lua}
-(%d+)
-local A,B="561","function";return {{{A,1,1,1,1,"main_chunk"},{A,3,7,23,1,B,"helper"},{A,7,1,30,2,B,"embracer.embrace"}},{},{19,0,23,17,3,0,30,25,26,3,0,15,0},{[4]="comment"}}
-abspath{spec/samples/bad_code.lua}
-(%d+)
-local A,B,C,D="561","helper","function","embrace";return {{{"112",1,1,7,"package",{"loaded",true}},{A,1,1,1,1,"main_chunk"},{A,3,7,26,1,C,B},{"211",3,16,21,B,true},{"212",3,23,25,"..."},{A,7,1,21,2,C,D},{"111",7,10,16,D,nil,nil,true},{"412",8,10,12,"opt",7,18,20},{"113",9,11,16,"hepler"}},{},{24,0,26,9,3,0,21,31,26,3,0,0},{[4]="comment"}}
-abspath{spec/samples/python_code.lua}
-(%d+)
-return {{{"011",1,6,15,"expected '=' near '__future__'"}},{},{},{}}
-]]):gsub("[%[%]%-]", "%%%0"), nil)
-         -- luacheck: pop
-
-         format_version = tonumber(format_version)
-         assert.number(format_version, "Cache string is:" .. cache)
-         assert.string(good_mtime)
-         assert.string(bad_mtime)
-         assert.string(python_mtime)
-
-         assert.equal(normal_output, get_output("spec/samples/good_code.lua spec/samples/bad_code.lua spec/samples/python_code.lua --std=lua52 --no-config --cache "..tmpname))
-
-         local function write_new_cache(version)
-            local fh = io.open(tmpname, "wb")
-            assert.userdata(fh)
-            fh:write(replace_abspath([[
-%s
-abspath{spec/samples/python_code.lua}
-%s
-return {{{"111", 1, 1, nil, "global"}, {"321", 6, 8, nil, "uninit"}},{},{1, 1, 1, 1, 1, 1},{}}
-abspath{spec/samples/good_code.lua}
-%s
-return {{{"011",5,7,nil, "this code is actually bad"}},{},{},{}}
-abspath{spec/samples/bad_code.lua}
-%s
-return {{},{},{}}]]):format(version, python_mtime, good_mtime, tostring(tonumber(bad_mtime) - 1)))
-            fh:close()
-         end
-
-         write_new_cache("\n"..tostring(format_version))
-         assert.equal(mocked_output,
-            get_output("spec/samples/good_code.lua spec/samples/bad_code.lua spec/samples/python_code.lua spec/samples/unused_code.lua --std=lua52 --no-config --cache "..tmpname))
-         assert.equal(mocked_output,
-            get_output("spec/samples/good_code.lua spec/samples/bad_code.lua spec/samples/python_code.lua spec/samples/unused_code.lua --std=lua52 --no-config --cache "..tmpname))
-
-         write_new_cache("\n"..tostring(format_version + 1))
-         assert.equal(normal_output, get_output("spec/samples/good_code.lua spec/samples/bad_code.lua spec/samples/python_code.lua --std=lua52 --no-config --cache "..tmpname))
-
-         write_new_cache("")
-         assert.equal(normal_output, get_output("spec/samples/good_code.lua spec/samples/bad_code.lua spec/samples/python_code.lua --std=lua52 --no-config --cache "..tmpname))
-      end)
-   end)
-
    if not multithreading.has_lanes then
       pending("uses multithreading")
    else
